### R code from vignette source 'cr_4.Rnw'

###################################################
### code chunk number 1: cr_4.Rnw:48-49
###################################################
pairs( ~ Clay1 + OC1 + CEC1, data=obs)


###################################################
### code chunk number 2: cr_4.Rnw:71-72
###################################################
names(obs)


###################################################
### code chunk number 3: cr_4.Rnw:77-79
###################################################
cov(obs[c(10,7,13)])
cor(obs[c(10,7,13)])


###################################################
### code chunk number 4: cr_4.Rnw:96-100
###################################################
cor(residuals(lm(CEC1 ~ Clay1)), residuals(lm(OC1 ~ Clay1)))
cor(residuals(lm(CEC1 ~ OC1)), residuals(lm(Clay1 ~ OC1)))
cor(CEC1, OC1)
cor(CEC1, Clay1)


###################################################
### code chunk number 5: cr_4.Rnw:113-131
###################################################
par(mfrow=c(1,2))
par(adj=0.5)
plot(CEC1 ~ Clay1, pch=20, cex=1.5, xlim=c(0,100),
     xlab="Clay %",
     ylab="CEC, cmol+ (kg soil)-1")
abline(h=mean(CEC1), lty=2); abline(v=mean(Clay1), lty=2)
title("Simple Correlation, Clay vs. CEC 0-10 cm")
text(80, 4, cex=1.5, paste("r =",round(cor(Clay1, CEC1), 3)))
mr.1 <- residuals(lm(CEC1 ~ OC1)); mr.2 <-residuals(lm(Clay1 ~ OC1))
plot(mr.1 ~ mr.2, pch=20, cex=1.5, xlim=c(-50, 50),
     xlab="Residuals, Clay vs. OC, %",
     ylab="Residuals, CEC vs. OC, cmol+ (kg soil)-1")
abline(h=mean(mr.1), lty=2); abline(v=mean(mr.2), lty=2)
title("Partial Correlation, Clay vs. CEC, correcting for OC 0-10 cm")
text(25, -6, cex=1.5, paste("r =",round(cor(mr.1, mr.2), 3)))
par(adj=0)
rm(mr.1, mr.2)
par(mfrow=c(1,1))


###################################################
### code chunk number 6: cr_4.Rnw:147-155
###################################################
p.cor <- function(x){ 
        inv <- solve(var(x)) 
        sdi <- diag(1/sqrt(diag(inv)))
        p.cor.mat <- -(sdi %*% inv %*% sdi)
        diag(p.cor.mat) <- 1
        rownames(p.cor.mat) <- colnames(p.cor.mat) <- colnames(x)
        return(p.cor.mat) }
p.cor(obs[c(10,7,13)])


###################################################
### code chunk number 7: cr_4.Rnw:190-194
###################################################
lmcec.null<-lm(CEC1 ~ 1); summary(lmcec.null)
lmcec.oc<-lm(CEC1 ~ OC1); summary(lmcec.oc)
lmcec.clay<-lm(CEC1 ~ Clay1); summary(lmcec.clay)
lmcec.oc.cl<-lm(CEC1 ~ OC1 + Clay1); summary(lmcec.oc.cl)


###################################################
### code chunk number 8: cr_4.Rnw:236-240
###################################################
summary(lmcec.null)$adj.r.squared
summary(lmcec.oc)$adj.r.squared
summary(lmcec.clay)$adj.r.squared
summary(lmcec.oc.cl)$adj.r.squared


###################################################
### code chunk number 9: cr_4.Rnw:251-252
###################################################
AIC(lmcec.null); AIC(lmcec.oc); AIC(lmcec.clay); AIC(lmcec.oc.cl) 


###################################################
### code chunk number 10: cr_4.Rnw:264-266
###################################################
(a <- anova(lmcec.oc.cl, lmcec.clay))
diff(a$RSS)/a$RSS[2]


###################################################
### code chunk number 11: cr_4.Rnw:274-276
###################################################
(a <- anova(lmcec.oc.cl, lmcec.oc))
diff(a$RSS)/a$RSS[2]


###################################################
### code chunk number 12: cr_4.Rnw:299-315
###################################################
par(mfrow=c(1,2))
tmp <- qqnorm(residuals(lmcec.oc.cl), pch=20,
     main="Normal Q-Q plot, residuals from lm(CEC1 ~ OC1 + Clay1)")
qqline(residuals(lmcec.oc.cl))
diff <- (tmp$x - tmp$y)
### label the residuals that deviate too far from the line
text(tmp$x, tmp$y, ifelse((abs(diff) > 3), names(diff), ""), pos=2)
rm(tmp,diff)
### observed vs. fitted
#
plot(CEC1 ~ fitted(lmcec.oc.cl), pch=20,
   xlim=c(0,30), ylim=c(0,30),
   xlab="Fitted",ylab="Observed",
   main="Observed vs. Fitted CEC, 0-10cm")
abline(0,1); grid(col="black")
par(mfrow=c(1,1))


###################################################
### code chunk number 13: cr_4.Rnw:346-348
###################################################
# let stepwise pick the best from a full model
lms <- step(lm(Clay2 ~ Clay1 + CEC1 + OC1))


###################################################
### code chunk number 14: cr_4.Rnw:364-365
###################################################
lms <- step(lm(Clay5 ~ Clay1 + CEC1 + OC1 + Clay2 + CEC2 + OC2, data=obs))


###################################################
### code chunk number 15: cr_4.Rnw:390-393
###################################################
lm5z <- lm(Clay5 ~ zone);  summary(lm5z)
lm51 <- lm(Clay5 ~ Clay1); summary(lm51)
lm5z1 <- lm(Clay5 ~ zone + Clay1);  summary(lm5z1)


###################################################
### code chunk number 16: cr_4.Rnw:428-429
###################################################
stem(residuals(lm5z1))


###################################################
### code chunk number 17: cr_4.Rnw:443-449
###################################################
res.lo <- which(residuals(lm5z1) < -12)
res.hi <- which(residuals(lm5z1) > 9)
obs[res.lo, ]
predict(lm5z1)[res.lo]
obs[res.hi, ]
predict(lm5z1)[res.hi]


###################################################
### code chunk number 18: cr_4.Rnw:500-502
###################################################
require(car)
vif(lm(Clay5 ~ Clay1 + CEC1 + OC1 + Clay2 + CEC2 + OC2, data=obs))


###################################################
### code chunk number 19: cr_4.Rnw:515-517
###################################################
vif(lm(Clay5 ~ Clay1 + CEC1 + OC1 + CEC2 + OC2, data=obs))
vif(lm(Clay5 ~ Clay2 + CEC1 + OC1 + CEC2 + OC2, data=obs))


###################################################
### code chunk number 20: cr_4.Rnw:528-530
###################################################
AIC(lm(Clay5 ~ Clay1 + CEC1 + OC1 + CEC2 + OC2, data=obs))
AIC(step(lm(Clay5 ~ Clay1 + CEC1 + OC1 + CEC2 + OC2, data=obs), trace=0))


###################################################
### code chunk number 21: cr_4.Rnw:535-537
###################################################
AIC(lm(Clay5 ~ Clay2 + CEC1 + OC1 + CEC2 + OC2, data=obs))
AIC(step(lm(Clay5 ~ Clay2 + CEC1 + OC1 + CEC2 + OC2, data=obs) , trace=0))


###################################################
### code chunk number 22: cr_4.Rnw:549-550
###################################################
(lms.2 <- step(lm(Clay5 ~ Clay2 + CEC1 + OC1 + CEC2 + OC2, data=obs)))


###################################################
### code chunk number 23: cr_4.Rnw:565-566
###################################################
vif(lms)


###################################################
### code chunk number 24: cr_4.Rnw:582-585
###################################################
AIC(lms)
AIC(update(lms, . ~ . - Clay1))
AIC(update(lms, . ~ . - Clay2))


###################################################
### code chunk number 25: cr_4.Rnw:601-625
###################################################
# scatterplot, coloured by zone
plot(Clay5 ~ Clay1, col=as.numeric(zone), pch=20)
# zone 1
abline(coefficients(lm5z1)["(Intercept)"] , coefficients(lm5z1)["Clay1"])
# zone 2
for (iz in 2:4) {
   abline(coefficients(lm5z1)["(Intercept)"] 
    +  coefficients(lm5z1)[iz]
   , coefficients(lm5z1)["Clay1"], col=iz) }
# univariate line
abline(lm51, lty=2, lwd=1.5)
# legend
text(70, 30, pos=2,
  paste("Slopes: parallel:",
  round(coefficients(lm5z1)["Clay1"],3),
  "; univariate:",
  round(coefficients(lm51)["Clay1"],3)));
text(70, 26, pos=2,
  paste("   AIC: parallel:", floor(AIC(lm5z1)),
  "; univariate:", floor(AIC(lm51))));
text(70, 22, pos=2,
  paste("Pr(>F) parallel is not better:",
  round(anova(lm5z1,lm51)$"Pr(>F)"[2],)))
for (iz in 1:4) { text(65, 50-(3*iz), paste("zone",iz), col=iz) }


###################################################
### code chunk number 26: cr_4.Rnw:651-653
###################################################
lm51.z <- lm(Clay5 ~ Clay1 * zone)
summary(lm51.z)


###################################################
### code chunk number 27: cr_4.Rnw:698-714
###################################################
plot(Clay1, Clay5, xlim=c(10,80), ylim=c(10,80), pch=20, 
    cex=1.5, col=as.numeric(zone),xlab="Topsoil clay %", ylab="Subsoil clay %");
title("Subsoil vs. topsoil clay, by zone");
text(65, 40, "Slope of regression");
for (z in 1:4) {
  m <- lm(Clay5 ~ Clay1, subset=(zone==z));
  text(65, 40-(3*z), paste("zone",z,":",round(coefficients(m)[2], 3)),
          col=z);
  m.l <- loess(Clay5 ~ Clay1, subset=(zone==z), span=100);
  lines(y=c(min(m.l$fitted), max(m.l$fitted)),
          x=c(min(m.l$x), max(m.l$x)), col=z);
};
m <- lm(Clay5 ~ Clay1);
abline(m, col=6, lwd=1.5, lty=2);
text(65, 25, paste("overall:", round(coefficients(m)[2], 3)), col=6);
rm(m, m.l, z)


###################################################
### code chunk number 28: cr_4.Rnw:721-737
###################################################
plot(Clay1, Clay5, xlim=c(10,80), ylim=c(10,80), pch=as.numeric(zone), 
    xlab="Topsoil clay %", ylab="Subsoil clay %")
title("Subsoil vs. topsoil clay, by zone")
legend(10,75, pch=1:4, lty=1:4, legend=1:4)
text(65, 40, "Slopes:")
for (z in 1:4) {
  m <- lm(Clay5 ~ Clay1, subset=(zone==z))
  text(65, 40-(3*z), paste("zone",z,":",round(coefficients(m)[2], 3)))
  m.l <- loess(Clay5 ~ Clay1, subset=(zone==z), span=100)
  lines(y=c(min(m.l$fitted), max(m.l$fitted)),
          x=c(min(m.l$x), max(m.l$x)), lty=z, lwd=1.5)
}
m <- lm(Clay5 ~ Clay1)
abline(m)
text(65, 25, paste("overall:", round(coefficients(m)[2], 3)))
rm(m, m.l, z)


###################################################
### code chunk number 29: cr_4.Rnw:758-759
###################################################
lm51.z.n <- lm(Clay5 ~ zone/Clay1); summary(lm51.z.n)


###################################################
### code chunk number 30: cr_4.Rnw:778-781
###################################################
coefficients(lm51.z.n)["zone4:Clay1"] -
        (coefficients(lm51.z)["Clay1"] +
        coefficients(lm51.z)["Clay1:zone4"])  


###################################################
### code chunk number 31: cr_4.Rnw:795-796
###################################################
summary(lm5z); summary(lm51.z.n); summary(lm51.z)


###################################################
### code chunk number 32: cr_4.Rnw:805-808
###################################################
model.matrix(lm5z1)[15:22,]
model.matrix(lm51.z)[15:22,]
model.matrix(lm51.z.n)[15:22,]


